@@ -1,5 +1,6 @@
-#' @details
-#' The 'svMisc' package is of general use among `SciViews::R`, a layer on top of
+#' Miscellaneous Functions for 'SciViews::R'
+#'
+#' The \{svMisc\} package is of general use among SciViews::R, a layer on top of
 #' R, and the tidyverse. This package collects together a series of general
 #' functions to manage a centralized environment for temporary variables, a
 #' progress bar and batch analysis mode, etc.
@@ -14,20 +15,17 @@
 #'
 #' - [parse_text()] to parse any R expression, including partial or incorrect
 #'   ones (fails gracefully).
-#' @keywords internal
-"_PACKAGE"
 
+## usethis namespace: start
 #' @importFrom utils RSiteSearch apropos available.packages browseURL
 #'   capture.output compareVersion file.edit file_test flush.console
 #'   getCRANmirrors getS3method install.packages installed.packages methods
 #'   object.size packageDescription remove.packages str tail write.table ? help
-#'   help.search apropos find
-#' @importFrom methods findFunction existsFunction new getMethods isGeneric
+#'   help.search apropos find txtProgressBar setTxtProgressBar
+#' @importFrom methods findFunction existsFunction new isGeneric
 #'   showMethods slot slotNames
-#' @importFrom stats runif
+#' @importFrom stats cor fft quantile rnorm runif
 #' @importFrom tools file_path_as_absolute
-# The following block is used by usethis to automatically manage
-# roxygen namespace tags. Modify with care!
-## usethis namespace: start
+#' @importFrom rlang is_interactive
 ## usethis namespace: end
-NULL
+"_PACKAGE"
